CollectionCRUD<T> class
abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
T t) → List< T> -
deleteAll(
) → List< T> -
get(
int index) → T -
getAll(
) → List< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
T t) → List< T> -
saveAll(
List< T> t) → List<T> -
toString(
) → String -
A string representation of this object.
inherited
-
update(
{required dynamic id, required T updatedValue}) → List< T>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited